<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-CAL-2_6_4-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-CAL-2_6_4-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-CAL-2_6_5-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/Term/InterestOnlyReason/@Description[.='Minimise Cash Flow Impact During Construction']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Minimise Cash Flow Impact During Construction</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Reason">
        <updated>
          <xsl:attribute name="name">Reason</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Reason">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Reason"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Minimise Cash Flow Impact During Construction</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Reason</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Minimise Cash Flow Impact During Construction</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/Term/InterestOnlyReason/@Description[.='Minimise Cash Flow Impact During the Bridging Period']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Minimise Cash Flow Impact During the Bridging Period</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Reason">
        <updated>
          <xsl:attribute name="name">Reason</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Reason">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Reason"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Minimise Cash Flow Impact During the Bridging Period</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Reason</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Minimise Cash Flow Impact During the Bridging Period</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='2.6.4']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">2.6.4</xsl:attribute>
      <xsl:attribute name="update">2.6.5</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
