<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-CAL-2_6_7-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-CAL-2_6_7-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-CAL-2_6_8-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ResponsibleLending/Mitigant/@Other[.=&quot;Co-Applicant's Income&quot;]">
    <removed>
      <xsl:attribute name="name">Other</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Co-Applicant's Income</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Factor">
        <updated>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Factor">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Factor"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Co-Applicant's Income</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Co-Applicant's Income</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ResponsibleLending/Mitigant/@Other[.='Savings or Superannuation']">
    <removed>
      <xsl:attribute name="name">Other</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Savings or Superannuation</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Factor">
        <updated>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Factor">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Factor"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Savings or Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Savings or Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ResponsibleLending/SignificantChange/@Description[.='End of Contract or Loss of Employment']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">End of Contract or Loss of Employment</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">End of Contract or Loss of Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">End of Contract or Loss of Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ResponsibleLending/SignificantChange/@Description[.='Extended Unpaid Leave']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Extended Unpaid Leave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Extended Unpaid Leave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Extended Unpaid Leave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ResponsibleLending/SignificantChange/@Description[.='Increased Debt Repayments for an Existing Loan']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Increased Debt Repayments for an Existing Loan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Increased Debt Repayments for an Existing Loan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Increased Debt Repayments for an Existing Loan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ResponsibleLending/SignificantChange/@Description[.='Leaving Employment']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Leaving Employment</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Leaving Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Leaving Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ResponsibleLending/SignificantChange/@Description[.='Medical Treatment or Illness']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Medical Treatment or Illness</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Medical Treatment or Illness</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Medical Treatment or Illness</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ResponsibleLending/Mitigant/@Other[.=&quot;Co-Applicant's Income&quot;]">
    <removed>
      <xsl:attribute name="name">Other</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Co-Applicant's Income</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Factor">
        <updated>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Factor">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Factor"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Co-Applicant's Income</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Co-Applicant's Income</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ResponsibleLending/Mitigant/@Other[.='Savings or Superannuation']">
    <removed>
      <xsl:attribute name="name">Other</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Savings or Superannuation</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Factor">
        <updated>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Factor">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Factor"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Savings or Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Savings or Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ResponsibleLending/SignificantChange/@Description[.='End of Contract or Loss of Employment']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">End of Contract or Loss of Employment</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">End of Contract or Loss of Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">End of Contract or Loss of Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ResponsibleLending/SignificantChange/@Description[.='Extended Unpaid Leave']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Extended Unpaid Leave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Extended Unpaid Leave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Extended Unpaid Leave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ResponsibleLending/SignificantChange/@Description[.='Increased Debt Repayments for an Existing Loan']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Increased Debt Repayments for an Existing Loan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Increased Debt Repayments for an Existing Loan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Increased Debt Repayments for an Existing Loan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ResponsibleLending/SignificantChange/@Description[.='Leaving Employment']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Leaving Employment</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Leaving Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Leaving Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ResponsibleLending/SignificantChange/@Description[.='Medical Treatment or Illness']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Medical Treatment or Illness</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Medical Treatment or Illness</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Medical Treatment or Illness</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ResponsibleLending/Mitigant/@Other[.=&quot;Co-Applicant's Income&quot;]">
    <removed>
      <xsl:attribute name="name">Other</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Co-Applicant's Income</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Factor">
        <updated>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Factor">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Factor"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Co-Applicant's Income</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Co-Applicant's Income</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ResponsibleLending/Mitigant/@Other[.='Savings or Superannuation']">
    <removed>
      <xsl:attribute name="name">Other</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Savings or Superannuation</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Factor">
        <updated>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Factor">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Factor"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Savings or Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Savings or Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ResponsibleLending/SignificantChange/@Description[.='End of Contract or Loss of Employment']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">End of Contract or Loss of Employment</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">End of Contract or Loss of Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">End of Contract or Loss of Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ResponsibleLending/SignificantChange/@Description[.='Extended Unpaid Leave']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Extended Unpaid Leave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Extended Unpaid Leave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Extended Unpaid Leave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ResponsibleLending/SignificantChange/@Description[.='Increased Debt Repayments for an Existing Loan']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Increased Debt Repayments for an Existing Loan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Increased Debt Repayments for an Existing Loan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Increased Debt Repayments for an Existing Loan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ResponsibleLending/SignificantChange/@Description[.='Leaving Employment']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Leaving Employment</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Leaving Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Leaving Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ResponsibleLending/SignificantChange/@Description[.='Medical Treatment or Illness']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Medical Treatment or Illness</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Medical Treatment or Illness</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Medical Treatment or Illness</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/FutureCircumstances/ResponsibleLending/Mitigant/@Other[.=&quot;Co-Applicant's Income&quot;]">
    <removed>
      <xsl:attribute name="name">Other</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Co-Applicant's Income</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Factor">
        <updated>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Factor">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Factor"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Co-Applicant's Income</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Co-Applicant's Income</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/FutureCircumstances/ResponsibleLending/Mitigant/@Other[.='Savings or Superannuation']">
    <removed>
      <xsl:attribute name="name">Other</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Savings or Superannuation</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Factor">
        <updated>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Factor">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Factor"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Savings or Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Factor</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Savings or Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/FutureCircumstances/ResponsibleLending/SignificantChange/@Description[.='End of Contract or Loss of Employment']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">End of Contract or Loss of Employment</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">End of Contract or Loss of Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">End of Contract or Loss of Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/FutureCircumstances/ResponsibleLending/SignificantChange/@Description[.='Extended Unpaid Leave']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Extended Unpaid Leave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Extended Unpaid Leave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Extended Unpaid Leave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/FutureCircumstances/ResponsibleLending/SignificantChange/@Description[.='Increased Debt Repayments for an Existing Loan']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Increased Debt Repayments for an Existing Loan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Increased Debt Repayments for an Existing Loan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Increased Debt Repayments for an Existing Loan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/FutureCircumstances/ResponsibleLending/SignificantChange/@Description[.='Leaving Employment']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Leaving Employment</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Leaving Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Leaving Employment</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/FutureCircumstances/ResponsibleLending/SignificantChange/@Description[.='Medical Treatment or Illness']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Medical Treatment or Illness</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Change">
        <updated>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Change">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Change"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Medical Treatment or Illness</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Change</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Medical Treatment or Illness</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='2.6.7']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">2.6.7</xsl:attribute>
      <xsl:attribute name="update">2.6.8</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
