<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-CNZ-2_0_9-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-CNZ-2_0_9-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-CNZ-2_0_8-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='M Capitol']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">M Capitol</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Cuscal']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cuscal</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/DepositAccountDetails/DocumentationInstructions/@x_DeliverTo">
    <removed>
      <xsl:attribute name="name">x_DeliverTo</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LendingGuarantee/Security/SecurityAgreement">
    <removed>
      <xsl:attribute name="name">SecurityAgreement</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='M Capitol']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">M Capitol</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Cuscal']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cuscal</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/DiscountMargin">
    <removed>
      <xsl:attribute name="name">DiscountMargin</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/DocumentationInstructions/@x_DeliverTo">
    <removed>
      <xsl:attribute name="name">x_DeliverTo</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/Repayment/@LoanPaymentScheduleType">
    <removed>
      <xsl:attribute name="name">LoanPaymentScheduleType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/Repayment/@Regular">
    <removed>
      <xsl:attribute name="name">Regular</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/Security/SecurityAgreement">
    <removed>
      <xsl:attribute name="name">SecurityAgreement</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/Software">
    <removed>
      <xsl:attribute name="name">Software</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/DocumentationInstructions/@x_DeliverTo">
    <removed>
      <xsl:attribute name="name">x_DeliverTo</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='M Capitol']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">M Capitol</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Cuscal']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cuscal</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='M Capitol']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">M Capitol</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Cuscal']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cuscal</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='M Capitol']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">M Capitol</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Cuscal']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cuscal</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/RegularRepayment/@LoanPaymentScheduleType">
    <removed>
      <xsl:attribute name="name">LoanPaymentScheduleType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/Security/SecurityAgreement">
    <removed>
      <xsl:attribute name="name">SecurityAgreement</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/Software">
    <removed>
      <xsl:attribute name="name">Software</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='M Capitol']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">M Capitol</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Cuscal']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cuscal</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/OtherIncome/@Type[.='Private Pension']">
    <removed>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Private Pension</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/OtherIncome/@Type[.='Superannuation']">
    <removed>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Superannuation</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/OtherIncome/@GovernmentBenefitsType[.='Age Pension']">
    <updated>
      <xsl:attribute name="name">GovernmentBenefitsType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Age Pension</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@BenefitsDescription">
        <updated>
          <xsl:attribute name="name">BenefitsDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@BenefitsDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@BenefitsDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Age Pension</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">BenefitsDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Age Pension</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/OtherIncome/@Type[.='Private Pension']">
    <updated>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Private Pension</xsl:attribute>
      <xsl:attribute name="update">Other Income</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@Description">
        <updated>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Description">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Description"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Private Pension</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Private Pension</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/OtherIncome/@Type[.='Superannuation']">
    <updated>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Superannuation</xsl:attribute>
      <xsl:attribute name="update">Other Income</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@Description">
        <updated>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Description">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Description"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Superannuation</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='M Capitol']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">M Capitol</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Cuscal']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cuscal</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/ProductSet">
    <removed>
      <xsl:attribute name="name">ProductSet</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/ProductSet/Contact/@x_MailingAddress">
    <removed>
      <xsl:attribute name="name">x_MailingAddress</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/ProductSet/Product/@x_FinancialProduct">
    <removed>
      <xsl:attribute name="name">x_FinancialProduct</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/DocumentationInstructions/@x_DeliverTo">
    <removed>
      <xsl:attribute name="name">x_DeliverTo</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@IsEstimated">
    <removed>
      <xsl:attribute name="name">IsEstimated</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@x_ProductSet">
    <removed>
      <xsl:attribute name="name">x_ProductSet</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@Type[.='Acceptance Fee']">
    <removed>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Acceptance Fee</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@Type[.='Early Repayment Admin Fee']">
    <removed>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Early Repayment Admin Fee</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@Type[.='Rollover Fee']">
    <removed>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rollover Fee</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@Type[.='Unused Facility Fee']">
    <removed>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Unused Facility Fee</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@Type[.='Rollover Fee']">
    <updated>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rollover Fee</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@Description">
        <updated>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Description">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Description"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rollover Fee</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rollover Fee</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@Type[.='Early Repayment Admin Fee']">
    <updated>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Early Repayment Admin Fee</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@Description">
        <updated>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Description">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Description"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Early Repayment Admin Fee</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Early Repayment Admin Fee</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@Type[.='Acceptance Fee']">
    <updated>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Acceptance Fee</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@Description">
        <updated>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Description">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Description"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Acceptance Fee</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Acceptance Fee</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@Type[.='Facility Fee']">
    <updated>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Facility Fee</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@Description">
        <updated>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Description">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Description"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Facility Fee</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Facility Fee</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='M Capitol']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">M Capitol</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Cuscal']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cuscal</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/ApplicableDuration">
    <removed>
      <xsl:attribute name="name">ApplicableDuration</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/Percentage">
    <removed>
      <xsl:attribute name="name">Percentage</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='M Capitol']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">M Capitol</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">M Capitol</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Cuscal']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cuscal</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Cuscal</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Instructions/ApplicationInstructions/Update/Status/@Name[.='Indicatively Approved']">
    <removed>
      <xsl:attribute name="name">Name</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Indicatively Approved</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Instructions/ApplicationInstructions/Update/Status/Condition/@ConditionType">
    <removed>
      <xsl:attribute name="name">ConditionType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Instructions/ApplicationInstructions/Update/Status/Condition/Product">
    <removed>
      <xsl:attribute name="name">Product</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='2.0.9']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">2.0.9</xsl:attribute>
      <xsl:attribute name="update">2.0.8</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
