<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-VAL-0_0_5-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-VAL-0_0_5-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-VAL-0_0_4-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/Contact/ContactPerson/@FirstName">
    <removed>
      <xsl:attribute name="name">FirstName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/Contact/ContactPerson/@NameTitle">
    <removed>
      <xsl:attribute name="name">NameTitle</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/Contact/ContactPerson/@Surname">
    <removed>
      <xsl:attribute name="name">Surname</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Afterpay']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Afterpay</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Zip Co']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Zip Co</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Afterpay']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Afterpay</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Zip Co']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Zip Co</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Afterpay']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Afterpay</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Zip Co']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Zip Co</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Afterpay']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Afterpay</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Zip Co']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Zip Co</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Afterpay']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Afterpay</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Zip Co']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Zip Co</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Afterpay']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Afterpay</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Zip Co']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Zip Co</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Afterpay']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Afterpay</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Zip Co']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Zip Co</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/RelatedCompany/Contact/ContactPerson/@FirstName">
    <removed>
      <xsl:attribute name="name">FirstName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/RelatedCompany/Contact/ContactPerson/@NameTitle">
    <removed>
      <xsl:attribute name="name">NameTitle</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/RelatedCompany/Contact/ContactPerson/@Surname">
    <removed>
      <xsl:attribute name="name">Surname</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Afterpay']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Afterpay</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Zip Co']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Zip Co</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/Contact/ContactPerson/@FirstName">
    <removed>
      <xsl:attribute name="name">FirstName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/Contact/ContactPerson/@NameTitle">
    <removed>
      <xsl:attribute name="name">NameTitle</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/Contact/ContactPerson/@Surname">
    <removed>
      <xsl:attribute name="name">Surname</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Afterpay']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Afterpay</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Afterpay</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Zip Co']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Zip Co</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Zip Co</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='0.0.5']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">0.0.5</xsl:attribute>
      <xsl:attribute name="update">0.0.4</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
