<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-CNZ-2_0_2-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-CNZ-2_0_2-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-CNZ-2_0_1-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/@CustomerSinceMonth">
    <removed>
      <xsl:attribute name="name">CustomerSinceMonth</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AMG']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AMIST']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='ANZ Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AV Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Aon Master Trust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AustSafe']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Australian Catholic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Australian Ethical']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AustralianSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='BUSSQ']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='CBUS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='CareSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Catholic Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Christian Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Club Plus Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Colonial First State']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='CommBank Financial Planner']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='EISS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Energy Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Equity Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Essential Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='First State Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='First Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='HESTA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='InTrust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Kinetic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='LUCRF']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Legal Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Local Government']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='MAP']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='MTAA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Media Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Mercer Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Mine Wealth and Wellbeing']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='NGS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='NSF Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='OneAnswer']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Plum']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Prime']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Russell Investments']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='SmartSave']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Statewide']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Sunsuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='TWUSUPER']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='TasPlan']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='VicSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Virgin Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Visions']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='AMG']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='AMIST']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='ANZ Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='AV Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Aon Master Trust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='AustSafe']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Australian Catholic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Australian Ethical']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='AustralianSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='BUSSQ']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='CBUS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='CareSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Catholic Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Christian Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Club Plus Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Colonial First State']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='CommBank Financial Planner']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='EISS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Energy Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Equity Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Essential Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='First State Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='First Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='HESTA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='InTrust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Kinetic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='LUCRF']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Legal Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Local Government']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='MAP']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='MTAA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Media Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Mercer Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Mine Wealth and Wellbeing']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='NGS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='NSF Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='OneAnswer']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Plum']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Prime']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Russell Investments']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='SmartSave']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Statewide']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Sunsuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='TWUSUPER']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='TasPlan']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='VicSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Virgin Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Visions']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='AMG']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='AMIST']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='ANZ Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='AV Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Aon Master Trust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='AustSafe']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Australian Catholic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Australian Ethical']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='AustralianSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='BUSSQ']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='CBUS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='CareSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Catholic Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Christian Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Club Plus Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Colonial First State']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='CommBank Financial Planner']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='EISS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Energy Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Equity Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Essential Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='First State Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='First Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='HESTA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='InTrust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Kinetic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='LUCRF']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Legal Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Local Government']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='MAP']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='MTAA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Media Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Mercer Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Mine Wealth and Wellbeing']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='NGS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='NSF Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='OneAnswer']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Plum']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Prime']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Russell Investments']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='SmartSave']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Statewide']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Sunsuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='TWUSUPER']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='TasPlan']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='VicSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Virgin Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Visions']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='AMG']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='AMIST']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='ANZ Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='AV Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Aon Master Trust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='AustSafe']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Australian Catholic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Australian Ethical']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='AustralianSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='BUSSQ']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='CBUS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='CareSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Catholic Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Christian Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Club Plus Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Colonial First State']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='CommBank Financial Planner']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='EISS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Energy Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Equity Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Essential Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='First State Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='First Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='HESTA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='InTrust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Kinetic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='LUCRF']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Legal Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Local Government']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='MAP']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='MTAA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Media Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Mercer Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Mine Wealth and Wellbeing']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='NGS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='NSF Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='OneAnswer']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Plum']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Prime']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Russell Investments']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='SmartSave']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Statewide']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Sunsuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='TWUSUPER']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='TasPlan']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='VicSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Virgin Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Visions']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='AMG']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='AMIST']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='ANZ Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='AV Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Aon Master Trust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='AustSafe']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Australian Catholic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Australian Ethical']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='AustralianSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='BUSSQ']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='CBUS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='CareSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Catholic Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Christian Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Club Plus Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Colonial First State']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='CommBank Financial Planner']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='EISS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Energy Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Equity Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Essential Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='First State Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='First Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='HESTA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='InTrust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Kinetic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='LUCRF']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Legal Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Local Government']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='MAP']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='MTAA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Media Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Mercer Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Mine Wealth and Wellbeing']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='NGS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='NSF Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='OneAnswer']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Plum']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Prime']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Russell Investments']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='SmartSave']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Statewide']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Sunsuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='TWUSUPER']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='TasPlan']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='VicSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Virgin Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Visions']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/@Type[.='Savings Account']">
    <removed>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Savings Account</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/@Type[.='Savings Account']">
    <updated>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Savings Account</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@Description">
        <updated>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Description">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Description"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Savings Account</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Description</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Savings Account</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='AMG']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='AMIST']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='ANZ Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='AV Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Aon Master Trust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='AustSafe']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Australian Catholic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Australian Ethical']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='AustralianSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='BUSSQ']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='CBUS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='CareSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Catholic Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Christian Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Club Plus Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Colonial First State']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='CommBank Financial Planner']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='EISS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Energy Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Equity Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Essential Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='First State Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='First Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='HESTA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='InTrust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Kinetic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='LUCRF']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Legal Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Local Government']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='MAP']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='MTAA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Media Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Mercer Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Mine Wealth and Wellbeing']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='NGS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='NSF Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='OneAnswer']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Plum']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Prime']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Russell Investments']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='SmartSave']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Statewide']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Sunsuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='TWUSUPER']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='TasPlan']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='VicSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Virgin Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Visions']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/Contact/CurrentAddress/Duration">
    <removed>
      <xsl:attribute name="name">Duration</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/Contact/PreviousAddress/Duration">
    <removed>
      <xsl:attribute name="name">Duration</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/Contact/PriorAddress/Duration">
    <removed>
      <xsl:attribute name="name">Duration</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/Employment/SelfEmployed/@Basis[.='Contract']">
    <removed>
      <xsl:attribute name="name">Basis</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Contract</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/Employment/SelfEmployed/@Basis[.='Temporary']">
    <removed>
      <xsl:attribute name="name">Basis</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Temporary</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/@CustomerSinceMonth">
    <removed>
      <xsl:attribute name="name">CustomerSinceMonth</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AMG']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AMIST']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='ANZ Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AV Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Aon Master Trust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AustSafe']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Australian Catholic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Australian Ethical']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AustralianSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='BUSSQ']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='CBUS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='CareSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Catholic Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Christian Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Club Plus Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Colonial First State']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='CommBank Financial Planner']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='EISS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Energy Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Equity Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Essential Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='First State Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='First Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='HESTA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='InTrust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Kinetic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='LUCRF']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Legal Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Local Government']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='MAP']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='MTAA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Media Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Mercer Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Mine Wealth and Wellbeing']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='NGS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='NSF Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='OneAnswer']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Plum']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Prime']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Russell Investments']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='SmartSave']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Statewide']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Sunsuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='TWUSUPER']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='TasPlan']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='VicSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Virgin Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Visions']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Debit Card']">
    <removed>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Debit Card</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Emergency Travel Document']">
    <removed>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Emergency Travel Document</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='New Zealand Certificate of Identity']">
    <removed>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">New Zealand Certificate of Identity</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='New Zealand Refugee Travel Document']">
    <removed>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">New Zealand Refugee Travel Document</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Australian Photo Firearms Licence']">
    <updated>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Photo Firearms Licence</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherDescription">
        <updated>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Photo Firearms Licence</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Photo Firearms Licence</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Centrelink or Social Security Card']">
    <updated>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Centrelink or Social Security Card</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherDescription">
        <updated>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Centrelink or Social Security Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Centrelink or Social Security Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Department of Veterans Affairs Card']">
    <updated>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Department of Veterans Affairs Card</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherDescription">
        <updated>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Department of Veterans Affairs Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Department of Veterans Affairs Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Motor Vehicle Registration or Insurance Papers']">
    <updated>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Motor Vehicle Registration or Insurance Papers</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherDescription">
        <updated>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Motor Vehicle Registration or Insurance Papers</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Motor Vehicle Registration or Insurance Papers</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Professional or Trade Association Card']">
    <updated>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Professional or Trade Association Card</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherDescription">
        <updated>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Professional or Trade Association Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Professional or Trade Association Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Property Insurance Papers']">
    <updated>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Property Insurance Papers</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherDescription">
        <updated>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Property Insurance Papers</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Property Insurance Papers</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Property Lease or Rental Agreement']">
    <updated>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Property Lease or Rental Agreement</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherDescription">
        <updated>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Property Lease or Rental Agreement</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Property Lease or Rental Agreement</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='State or Federal Government Employee Photo Identity Card']">
    <updated>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">State or Federal Government Employee Photo Identity Card</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherDescription">
        <updated>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">State or Federal Government Employee Photo Identity Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">State or Federal Government Employee Photo Identity Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@DocumentType[.='Tertiary Education Institution Photo Identity Card']">
    <updated>
      <xsl:attribute name="name">DocumentType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Tertiary Education Institution Photo Identity Card</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherDescription">
        <updated>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherDescription">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherDescription"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Tertiary Education Institution Photo Identity Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherDescription</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Tertiary Education Institution Photo Identity Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/RelatedPerson/PersonName/@KnownAs">
    <removed>
      <xsl:attribute name="name">KnownAs</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@PaymentTiming">
    <removed>
      <xsl:attribute name="name">PaymentTiming</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@x_FinancialProduct">
    <removed>
      <xsl:attribute name="name">x_FinancialProduct</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@x_Security">
    <removed>
      <xsl:attribute name="name">x_Security</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='AMG']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='AMIST']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='ANZ Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='AV Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Aon Master Trust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='AustSafe']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Australian Catholic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Australian Ethical']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='AustralianSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='BUSSQ']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='CBUS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='CareSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Catholic Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Christian Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Club Plus Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Colonial First State']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='CommBank Financial Planner']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='EISS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Energy Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Equity Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Essential Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='First State Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='First Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='HESTA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='InTrust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Kinetic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='LUCRF']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Legal Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Local Government']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='MAP']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='MTAA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Media Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Mercer Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Mine Wealth and Wellbeing']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='NGS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='NSF Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='OneAnswer']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Plum']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Prime']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Russell Investments']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='SmartSave']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Statewide']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Sunsuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='TWUSUPER']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='TasPlan']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='VicSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Virgin Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Visions']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/LoanToValuationRatio">
    <removed>
      <xsl:attribute name="name">LoanToValuationRatio</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/LoanToValuationRatio/ContributingValuation/@x_Valuation">
    <removed>
      <xsl:attribute name="name">x_Valuation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults">
    <removed>
      <xsl:attribute name="name">ServiceabilityResults</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/NetDisposableIncome/@Amount">
    <removed>
      <xsl:attribute name="name">Amount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/NetDisposableIncome/@Frequency">
    <removed>
      <xsl:attribute name="name">Frequency</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/TotalGrossIncome/@Amount">
    <removed>
      <xsl:attribute name="name">Amount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/TotalGrossIncome/@Frequency">
    <removed>
      <xsl:attribute name="name">Frequency</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/TotalNetIncome/@Amount">
    <removed>
      <xsl:attribute name="name">Amount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/TotalNetIncome/@Frequency">
    <removed>
      <xsl:attribute name="name">Frequency</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/TotalSystemCalculatedLivingExpenses/@Amount">
    <removed>
      <xsl:attribute name="name">Amount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/TotalSystemCalculatedLivingExpenses/@Frequency">
    <removed>
      <xsl:attribute name="name">Frequency</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/TotalUserStatedLivingExpenses/@Amount">
    <removed>
      <xsl:attribute name="name">Amount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/ServiceabilityResults/TotalUserStatedLivingExpenses/@Frequency">
    <removed>
      <xsl:attribute name="name">Frequency</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/@CustomerSinceMonth">
    <removed>
      <xsl:attribute name="name">CustomerSinceMonth</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AMG']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AMIST']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='ANZ Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AV Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Aon Master Trust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AustSafe']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Australian Catholic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Australian Ethical']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='AustralianSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='BUSSQ']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='CBUS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='CareSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Catholic Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Christian Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Club Plus Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Colonial First State']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='CommBank Financial Planner']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='EISS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Energy Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Equity Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Essential Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='First State Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='First Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='HESTA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='InTrust']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Kinetic']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='LUCRF']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Legal Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Local Government']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='MAP']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='MTAA']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Media Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Mercer Wealth']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Mine Wealth and Wellbeing']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='NGS']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='NSF Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='OneAnswer']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Plum']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Prime']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Russell Investments']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='SmartSave']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Statewide']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Sunsuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='TWUSUPER']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='TasPlan']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='VicSuper']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Virgin Super']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Visions']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/@UniqueID">
    <removed>
      <xsl:attribute name="name">UniqueID</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Instructions/ApplicationInstructions/Submit/@IsSubmissionDocuments">
    <removed>
      <xsl:attribute name="name">IsSubmissionDocuments</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Instructions/ApplicationInstructions/Update/Status/Condition/@x_SupportingDocument">
    <removed>
      <xsl:attribute name="name">x_SupportingDocument</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='2.0.2']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">2.0.2</xsl:attribute>
      <xsl:attribute name="update">2.0.1</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
